# -*- coding: utf-8 -*-
# Description: Tests for the redirector module
#
# Copyright:
# Copyright (C) 2011 Bundesamt fur Sicherheit in der Informationstechnik
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2,
# or, at your option, any later version as published by the Free
# Software Foundation
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.

import unittest
import os
import os.path

#FIXME: there has to be a better way to do this
from mapwoc.redirector.redirector import mapping_from_file

class TestMappingFromFile(unittest.TestCase):
    def setUp(self):
        invalidFormat = """
[empty]
[not empty]
http://www.valid.url
http://www.valid2.url
"""
        invalidFormat2 = """
[sadasd}
http://www.valid.url
http://www.valid2.url
"""


        invalidURLS = """
hattp://blub.de
http://valid.url
gubbelgubbel
"""

        validMapping = """
[test_machine]
http://gubbel.de


http://guppel.de
[test_machine2]

http://gubbel.de

http://guppel.de
"""
        if not os.path.isdir("tests/tmp"):
            os.mkdir("tests/tmp")
        with open(os.path.join("tests/tmp", "invalidFormat"),"w") as fname:
            fname.write(invalidFormat)
        with open(os.path.join("tests/tmp", "invalidFormat2"),"w") as fname:
            fname.write(invalidFormat2)
        with open(os.path.join("tests/tmp", "invalidURLS"),"w") as fname:
            fname.write(invalidURLS)
        with open(os.path.join("tests/tmp", "validMapping"),"w") as fname:
            fname.write(validMapping)

    def tearDown(self):
        for base in ('invalidFormat', 'invalidFormat2', 'invalidURLS',
                     'validMapping'):
            os.remove(os.path.join('tests/tmp', base))


    def test_invalidFormat(self):
        mapping = mapping_from_file(
                    os.path.join("tests/tmp/invalidFormat"))
        self.assertEqual(mapping["empty"], None,
                "Empty mapping returns not None: %s" % mapping)
        self.assertEqual(mapping["not empty"], [ "http://www.valid.url",
                                                  "http://www.valid2.url"],
                               "Mapping not empty is wrong: %s" % mapping)

    def test_invalidFormat2(self):
        mapping = mapping_from_file(
              os.path.join("tests/tmp/invalidFormat2"))
        self.assertEqual(mapping[""], [ "http://www.valid.url",
                                        "http://www.valid2.url" ],
                "Invalid Mapping not switching to sample mode: %s" % mapping)

    def test_invalidURLS(self):
        mapping = mapping_from_file(
              os.path.join("tests/tmp/invalidURLS"))
        self.assertEqual(mapping[""], [ "http://valid.url" ],
                "Invalid URLS not filtered: %s" % mapping)

    def test_validMapping(self):
        mapping = mapping_from_file(
              os.path.join("tests/tmp/validMapping"))
        self.assertEqual(mapping["test_machine"], ["http://gubbel.de",
                                                    "http://guppel.de", ],
                                                    mapping)
        self.assertEqual(mapping["test_machine2"], ["http://gubbel.de",
                                                     "http://guppel.de" ],
                                                    mapping)
