# -*- coding: utf-8 -*-

# Description: Tests for scripts-functionality..
#
# Authors:
# Felix Wolfsteller <felix.wolfsteller@intevation.de>
#
# Copyright:
# Copyright (C) 2011 Bundesamt fur Sicherheit in der Informationstechnik
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2,
# or, at your option, any later version as published by the Free
# Software Foundation
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.

import unittest
import os
import os.path

from mapwoc.lib.hccontrol import HCControl
from mapwoc.nodectrl.kvmhcrunprocess import Script

class TestScript(unittest.TestCase):
    def setUp(self):
        hcfilecontent_wo_shortcuts = """
[lenny_iceweasel_base]
name=Lenny base, Konqueror 3.5.9
description=Debian Lenny 5.0.8 (base)
hcsid=lenny_konqueror_base
max_parallel=-1
controllable=true
active_browser=cpe:/a:konqueror:konqueror:3.5.9
os=cpe:/o:debian:debian_linux:5.0
installed_software=cpe:/o:debian:debian_linux:5.0

[control]
type=kvm
image_master=/usr/share/images/lenny-master.img
image_file=/usr/share/images/lenny_konqueror_base.ovl
image_snapshot=/usr/share/images/lenny_konqueror_base.snapshot
image_memory=128

[network]
own_ip=10.0.0.4
dns_ip=10.0.2.3
gateway_ip=10.0.0.1
proxy_ip=
homepage=http://10.0.0.1/lenny_konqueror_base

[keyboard-shortcuts]
homepage=alt-8
"""
        if not os.path.isdir("tests/tmp"):
            os.mkdir("tests/tmp")
        with open(os.path.join("tests/tmp", "lenny_iceweasel_base"),"w") as fname:
            fname.write(hcfilecontent_wo_shortcuts)

    def test_empty_script(self):
        script = Script()
        self.assertFalse(script.needs_action(1), "Empty Script does not work.")

    def test_empty_script2(self):
        script = Script()
        self.assertEqual(script.next_action(), None, "Empty Script has non-None next action.")
    
    def test_empty_script3(self):
        script = Script([])
        self.assertFalse(script.needs_action(1), "Empty Script does not work.")

    def test_empty_script4(self):
        script = Script([])
        self.assertEqual(script.next_action(), None, "Empty Script has non-None next action.")

    def test_do_script(self):
        script = Script([(1, 'a'),
                         (2, 'b'),
                         (4, 'd')])
        self.assertTrue(script.needs_action(1), "Error in Script processing/1.")
        self.assertEqual(script.next_action(), 'a', "Error in Script processing/a.")
        script.action_done()
        self.assertTrue(script.needs_action(2), "Error in Script processing/2.")
        self.assertEqual(script.next_action(), 'b', "Error in Script processing/b.")
        script.action_done()
        self.assertFalse(script.needs_action(3), "Error in Script processing/3.")
        self.assertTrue(script.needs_action(4), "Error in Script processing/4.")
        self.assertEqual(script.next_action(), 'd', "Error in Script processing/d.")
        script.action_done()
        self.assertFalse(script.needs_action(5), "Error in Script processing/5.")
        self.assertEqual(script.next_action(), None, "Error in Script processing/-.")
        script.action_done()


    def test_script_sorts(self):
        script = Script([(200, 'b'), (100, 'a')])
        self.assertEqual(script.next_action(), 'a', "Script does not sort input.")
        script.action_done()
        self.assertEqual(script.next_action(), 'b', "Script makes mistakes sorting input.")

    def test_script_shortcut_override(self):
        hc = HCControl(os.path.join("tests/tmp/lenny_iceweasel_base"))
        # TODO
        self.assertEqual(hc.SHORTCUT_HOMEPAGE, "alt-8", "HP-shortcut-Value does not match.")

    def tearDown(self):
        os.remove(os.path.join('tests/tmp', 'lenny_iceweasel_base'))

